@@ -44,11 +44,6 @@
 ;; A version of uniquify.el that works under Emacs 18, Emacs 19, XEmacs 19,
 ;; and InfoDock is available from the maintainer.
 
-;; Doesn't work under NT when backslash is used as a path separator (forward
-;;   slash path separator works fine).  To fix, check system-type against
-;;   'windows-nt, write a routine that breaks paths down into components.
-;;   (Surprisingly, there isn't one built in.)
-
 ;;; Change Log:
 
 ;; Originally by Dick King <king@reasoning.com> 15 May 86
@@ -282,6 +277,10 @@ Works on dired buffers and ordinary file-visiting buffers, but no others."
     (uniquify-rationalize-conflicting-sublist
      conflicting-sublist old-name depth)))
 
+(defvar uniquify-directory-matching-regexp
+  (format "\\(^\\|%1$s[^%1$s]*\\)%1$s"
+	  (regexp-quote (string directory-sep-char))))
+
 (defun uniquify-get-proposed-name (item depth)
   (let (index
 	(extra-string "")
@@ -290,7 +289,7 @@ Works on dired buffers and ordinary file-visiting buffers, but no others."
 	(fn (uniquify-fix-item-filename item)))
     (while (and (> n 0)
 		(setq index (string-match
-			     (concat "\\(^\\|/[^/]*\\)/"
+			     (concat uniquify-directory-matching-regexp
 				     (regexp-quote extra-string)
 				     (regexp-quote base)
 				     "\\'")
@@ -368,12 +367,14 @@ Works on dired buffers and ordinary file-visiting buffers, but no others."
 	(len (length instring))
 	(sep (or uniquify-separator "\\")))
     (while (< cursor len)
-      (if (= (aref instring cursor) ?/)
+      (if (= (aref instring cursor) directory-sep-char)
           (setq sofar (cons sep sofar)
                 cursor (1+ cursor))
-        (let ((first-slash (or (string-match "/" instring cursor) len)))
-          (setq sofar (cons (substring instring cursor first-slash) sofar)
-                cursor first-slash))))
+        (let ((first-dirsep (or (string-match (string directory-sep-char)
+					     instring cursor)
+			       len)))
+          (setq sofar (cons (substring instring cursor first-dirsep) sofar)
+                cursor first-dirsep))))
     (apply (function concat) sofar)))
 
 
